@@ -657,7 +657,7 @@ def __run_docker_compose_config(config, contents, env):
         try:
             d["DOCKER_GROUP_ID"] = str(grp.getgrnam("docker").gr_gid)
         except KeyError:
-            d["DOCKER_GROUP_ID"] = 0
+            d["DOCKER_GROUP_ID"] = "0"
 
         conf = subprocess.check_output(cmdline, cwd=temp_path, env=d)
         conf = yaml.safe_load(conf)
